# -*- coding: ISO-8859-1 -*-
# generated by wxGlade 0.3.5.1 on Fri Jul 01 17:02:46 2005

# This file is part of Platitude

""" The application frame window.
"""

__copyright__ = 'Copyright 2005, Ned Batchelder, All rights reserved.'
__author__ = 'Ned Batchelder'
__revision__ = '$Rev: 29 $'

import wx
import os

# begin wxGlade: dependencies
from LatCanvas import LatCanvas
# end wxGlade

from LatModel import LatModel
from NewDialog import NewDialog
from Utilities import *

[
    # File
    midNew, midOpen, midSave, midSaveAs, midTriplicate, midExit,
    # Help
    midAbout,
] = [wx.NewId() for i in range(7)]

class LatFrame(wx.Frame):
    def __init__(self, *args, **kwds):
        # When loading images below, it's very convenient to let the path
        # be relative to the program directory.  To do that, we cd to the
        # program directory here, then cd back at the end.
        curdir = os.getcwd()
        os.chdir(getProgramDir())
        
        # begin wxGlade: LatFrame.__init__
        kwds["style"] = wx.DEFAULT_FRAME_STYLE
        wx.Frame.__init__(self, *args, **kwds)
        
        # Menu Bar
        self.MainFrame_menubar = wx.MenuBar()
        self.SetMenuBar(self.MainFrame_menubar)
        wxglade_tmp_menu = wx.Menu()
        wxglade_tmp_menu.Append(midNew, "&New...\tCtrl-N", "Create a new lattice", wx.ITEM_NORMAL)
        wxglade_tmp_menu.Append(midOpen, "&Open...\tCtrl-O", "Open a platitude file", wx.ITEM_NORMAL)
        wxglade_tmp_menu.Append(midSave, "&Save\tCtrl-S", "Save the current lattice", wx.ITEM_NORMAL)
        wxglade_tmp_menu.Append(midSaveAs, "Save &As...", "", wx.ITEM_NORMAL)
        wxglade_tmp_menu.AppendSeparator()
        wxglade_tmp_menu.Append(midExit, "E&xit", "", wx.ITEM_NORMAL)
        self.MainFrame_menubar.Append(wxglade_tmp_menu, "&File")
        wxglade_tmp_menu = wx.Menu()
        wxglade_tmp_menu.Append(midTriplicate, "&Triplicate", "", wx.ITEM_NORMAL)
        self.MainFrame_menubar.Append(wxglade_tmp_menu, "&Edit")
        wxglade_tmp_menu = wx.Menu()
        wxglade_tmp_menu.Append(midAbout, "&About", "What's up with this software anyway?", wx.ITEM_NORMAL)
        self.MainFrame_menubar.Append(wxglade_tmp_menu, "&Help")
        # Menu Bar end
        self.canvas = LatCanvas(self, -1)

        self.__set_properties()
        self.__do_layout()
        # end wxGlade

        self.model = None
        
        wx.EVT_MENU(self, midNew, self.onNew)
        wx.EVT_MENU(self, midOpen, self.onOpen)
        wx.EVT_MENU(self, midSave, self.onSave)
        wx.EVT_MENU(self, midSaveAs, self.onSaveAs)
        wx.EVT_MENU(self, midTriplicate, self.onTriplicate)
        wx.EVT_MENU(self, midExit, self.onExit)
        wx.EVT_MENU(self, midAbout, self.onAbout)

        wx.EVT_UPDATE_UI(self, midSave, self.onHasModel_Update)
        wx.EVT_UPDATE_UI(self, midSaveAs, self.onHasModel_Update)
        wx.EVT_UPDATE_UI(self, midTriplicate, self.onHasModel_Update)

        wx.EVT_CLOSE(self, self.onClose)

        os.chdir(curdir)
        
    def __set_properties(self):
        # begin wxGlade: LatFrame.__set_properties
        self.SetTitle("Platitude")
        self.SetSize((532, 470))
        # end wxGlade

        # Set my own icon, to get it right with multiple sizes.
        ib = wx.IconBundle()
        ib.AddIconFromFile("platitude.ico", wx.BITMAP_TYPE_ANY)
        self.SetIcons(ib)

    def __do_layout(self):
        # begin wxGlade: LatFrame.__do_layout
        sizer_1 = wx.BoxSizer(wx.VERTICAL)
        sizer_1.Add(self.canvas, 1, wx.EXPAND, 0)
        self.SetAutoLayout(True)
        self.SetSizer(sizer_1)
        self.Layout()
        # end wxGlade

    def onClose(self, event):
        if self.maybeSaveDirty() == wx.CANCEL:
            return
        self.Destroy()
        
    def onHasModel_Update(self, event):
        event.Enable(self.model != None)

    def maybeSaveDirty(self):
        res = wx.OK
        if self.model and self.model.dirty:
            res = wx.MessageBox("Do you want to save changes?", "Platitude", wx.YES_NO+wx.CANCEL)
            if res == wx.YES:
                res = self.onSave(None)
        return res
    
    def onNew(self, ev):
        if self.maybeSaveDirty() == wx.CANCEL:
            return
        dlg = NewDialog(self)
        if dlg.ShowModal() == wx.OK:
            self.model = LatModel()
            self.model.MakeHatch(dlg.across, dlg.down)
            #print self.model.size
            self.canvas.SetModel(self.model)
        dlg.Destroy()

    def onOpen(self, ev):
        if self.maybeSaveDirty() == wx.CANCEL:
            return
        dlg = wx.FileDialog(self,
            message="Open lattice",
            defaultDir=os.getcwd(), 
            style=wx.OPEN,
            wildcard="Platitude files (*.lat)|*.lat|All files (*.*)|*.*"
            )

        if dlg.ShowModal() == wx.ID_OK:
            path = dlg.GetPath()
            self.model = LatModel()
            self.model.Open(path)
            self.canvas.SetModel(self.model)

        dlg.Destroy()
        
    def onSave(self, ev):
        if self.model.path:
            self.model.Save()
            res = wx.OK
        else:
            res = self.onSaveAs(ev)
        return res
    
    def onSaveAs(self, ev):
        dlg = wx.FileDialog(self,
            message="Save lattice",
            defaultDir=os.getcwd(), 
            style=wx.SAVE + wx.OVERWRITE_PROMPT,
            wildcard="Platitude files (*.lat)|*.lat|All files (*.*)|*.*"
            )

        res = dlg.ShowModal()
        if res == wx.ID_OK:
            path = dlg.GetPath()
            self.model.Save(path)
            res = wx.OK
        elif res == wx.ID_CANCEL:
            res = wx.CANCEL
            
        dlg.Destroy()        
        return res
    
    def onTriplicate(self, ev):
        import profile
        profile.runctx('self.foo()', globals(), locals(), 'trip.prof')

    def foo(self):    
        self.model.Triplicate()
        self.canvas.SetModel(self.model)

    def onExit(self, ev):
        self.Close()

    def onAbout(self, ev):
        wx.MessageBox(
            "Platitude %s\nby Ned Batchelder\nhttp://nedbatchelder.com   " % (wx.GetApp().version),
            "About Platitude", wx.OK | wx.ICON_INFORMATION
        )
        
# end of class LatFrame
